@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Calculate date-time operations
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use strict;
 use warnings;
@@ -124,7 +124,7 @@ Bot::BasicBot::Pluggable::Module::DateTimeCalc - Calculate date-time operations
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -144,9 +144,13 @@ supported.
 
 =head1 METHODS
 
+=head2 new()
+
+Create a new C<Bot::BasicBot::Pluggable::Module::DateTimeCalc> object.
+
 =head2 help()
 
-Show the keyword help text.
+Show the keyword help message.
 
 =head2 said()
 
@@ -154,6 +158,12 @@ Process the date-time calculations.
 
 =head1 IRC COMMANDS
 
+=head2 help
+
+  > TimeBot: help
+
+Show the keyword help message.
+
 =head2 source
 
   > TimeBot: source
